@@ -30,7 +30,7 @@ main (int argc, char **argv)
 
   /* call the config file parser */
   if (test_conf_parser_cmd_parser_config_file
-      ("./test_conf2.conf", &args_info, params) != 0) {
+      ("../../tests/test_conf2.conf", &args_info, params) != 0) {
     result = 1;
     goto stop;
   }
